@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-export URL="http://pi1139.physik.uni-erlangen.de/data/latest"
+export URL="https://sftp.km3net.de/data/v17.0.0/"
 if [ ! -d "pdfs" ]; then
     echo "Retrieving PDFs..."
     mkdir pdfs
